@@ -16,6 +16,7 @@ from .meta import repo_url, version
 
 class BaseDownloadMethod(object):
     def __init__(self, provider):
+        self.files = []
         self.provider = provider
         self.log = provider.log
         self.http = self.provider.http
@@ -46,6 +47,7 @@ class OnePerOneDownloader(BaseDownloadMethod):
     def download_chapter(self, chapter_url, path):
         self.chapter_url = chapter_url
         self.path = path
+        self.__pages_cache = []
         try:
             self.files = self.provider.get_files()
             self._loop_files()
@@ -159,7 +161,7 @@ class OnePerOneDownloader(BaseDownloadMethod):
     def _book_info_xml(self):
         comic_info = ComicInfo()
 
-        comic_info.volume(self.provider.get_chapter_index())
+        comic_info.number(self.provider.get_chapter_index())
         comic_info.title(self.provider.name)
         comic_info.pages(self.__pages_cache)
         comic_info.page_count(str(len(self.__pages_cache)))
