@@ -20,7 +20,7 @@ class HentaiFoxCom(Provider, Std):
         return self.http_get(url)
 
     def get_manga_name(self) -> str:
-        return self.text_content(self.content, self._name_selector)
+        return self.text_content_full(self.content, self._name_selector)
 
     def get_chapters(self):
         return [b'']
