@@ -54,9 +54,6 @@ class TmoFansCom(Provider, Std):
     def get_cover(self) -> str:
         return self._cover_from_content('.book-thumbnail')
 
-    def prepare_cookies(self):
-        self.cf_scrape(self.get_url())
-
     def chapter_for_json(self) -> str:
         return self.chapter[1]
 
